summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorelie <elie>2014-06-16 16:33:41 +0000
committerelie <elie>2014-06-16 16:33:41 +0000
commit8100a85271740bff7243f7b55a28182d6b936ae1 (patch)
tree3c7aeb28f397954260d70c84c073be69bc5e648d
parentaea9bae36a47b7c56fd07bd6acb9d9a8feac3e3e (diff)
downloadpysnmp-8100a85271740bff7243f7b55a28182d6b936ae1.tar.gz
contextEngineId & contextName values updated
-rw-r--r--examples/v3arch/twisted/manager/cmdgen/get-v3-custom-context.py11
1 files changed, 6 insertions, 5 deletions
diff --git a/examples/v3arch/twisted/manager/cmdgen/get-v3-custom-context.py b/examples/v3arch/twisted/manager/cmdgen/get-v3-custom-context.py
index 64fe2a3..516bbba 100644
--- a/examples/v3arch/twisted/manager/cmdgen/get-v3-custom-context.py
+++ b/examples/v3arch/twisted/manager/cmdgen/get-v3-custom-context.py
@@ -3,8 +3,9 @@
#
# Send a SNMP GET request
# with SNMPv3 with user 'usr-md5-none', SHA auth and no privacy protocols
# for MIB instance identified by contextEngineId: 8000000001020304,
# contextName: my-context
# using Twisted framework for network transport
# over IPv4/UDP
# to an Agent at 195.218.195.228:161
@@ -12,7 +13,7 @@
#
# This script performs similar to the following Net-SNMP command:
#
-# $ snmpget -v3 -l authNoPriv -u usr-md5-none -A authkey1 -E 8000000001020304 -n my-context -ObentU 195.218.195.228:161 1.3.6.1.2.1.1.1.0
+# $ snmpget -v3 -l authNoPriv -u usr-md5-none -A authkey1 -E 80004fb805636c6f75644dab22cc -n da761cfc8c94d3aceef4f60f049105ba -ObentU 195.218.195.228:161 1.3.6.1.2.1.1.1.0
#
from twisted.internet import reactor, defer
from pysnmp.entity import engine, config
@@ -73,8 +74,8 @@ df = cmdgen.GetCommandGenerator().sendReq(
snmpEngine,
'my-router',
( ('1.3.6.1.2.1.1.1.0', None), ),
- contextEngineId=rfc1902.OctetString(hexValue='8000000001020304'),
- contextName=rfc1902.OctetString('my-context')
+ contextEngineId=rfc1902.OctetString(hexValue='80004fb805636c6f75644dab22cc'),
+ contextName=rfc1902.OctetString('da761cfc8c94d3aceef4f60f049105ba')
)
# Register error/response receiver function at deferred
@@ -3,8 +3,9 @@
# Send a SNMP GET request
# with SNMPv3 with user 'usr-md5-none', SHA auth and no privacy protocols
-# for MIB instance identified by contextEngineId: 8000000001020304,
-# contextName: my-context
+# for MIB instance identified by
+# contextEngineId: 80004fb805636c6f75644dab22cc
+# contextName: da761cfc8c94d3aceef4f60f049105ba
# using Twisted framework for network transport
# over IPv4/UDP